pub fn parse_session_path(path: &Path) -> Option<AgentSession>Expand description
Parse a session file by path, detecting the agent type automatically.
pub fn parse_session_path(path: &Path) -> Option<AgentSession>Parse a session file by path, detecting the agent type automatically.